@@ -5,11 +5,12 @@ import sys
 
 help = '''
 NAME
-    qaws.py -- Query AWS CloudWatch logs
+    qaws -- Query AWS CloudWatch logs
 SYNOPSIS
-    qaws.py [-g groups...] \
-            [-t starttime | starttime endtime] \
+    qaws    [-g groups...]
+            [-t starttime | starttime endtime]
             [-q query]
+            [-s recordseparator]
 DESCRIPTION
     -g --groups groups ...
         Specify 1 to N logging groups like "/ecs/someservice1"
@@ -30,36 +31,38 @@ DESCRIPTION
             fields @timestamp, @message 
             | filter @message like 'event' 
             | limit 10"
+    -s --separator recordseparator
+        Optional parameter. Records will be separated by recordseparator symbol.
+        
     - It can take few minutes (~2 minutes) until logs appears in CloudWatch and therefore fetching logs 
         with '-t "1m"' may not return any results
-    - Even if you set '|limit 1' in --query then CloudWatch will anyway search over entire specified '-t "10d"' 
+    - Even if you set '|limit 1' in --query then CloudWatch will anyway search over entire specified e.g. '-t "10d"' 
         history which can take lot of time
 EXAMPLES
-    qaws.py \
-        --groups      "/ecs/myservice0" \
-        --time        "1h" \
+    qaws
+        --groups      "/ecs/myservice0"
+        --time        "1h"
         --query       "fields @message"
-    qaws.py \
-        --groups      "/ecs/myservice0" "/ecs/myservice1" "/ecs/myservice2" \
-        --time        "1h 30m" \
+    qaws
+        --groups      "/ecs/myservice0" "/ecs/myservice1" "/ecs/myservice2"
+        --time        "1h 30m"
         --query       "fields @message"
-    qaws.py \
-        --groups      "/ecs/myservice0" \
-        --time        "1h" "30m" \
+    qaws
+        --groups      "/ecs/myservice0"
+        --time        "5h" "1h"
         --query       "fields @timestamp @message | filter @message like 'event' | limit 15"
-    qaws.py \
-        --groups      "/ecs/myservice0" \
-        --time        "2020-05-24T00:00:00" "2020-05-24T12:00:00" \
+    qaws
+        --groups      "/ecs/myservice0"
+        --time        "2020-05-24T00:00:00" "2020-05-24T12:00:00"
         --query       "fields @message | filter @message like 'event'"
-    qaws.py \
-        --groups      "/ecs/myservice0" \
-        --time        "1y" "2020-05-24T00:00:00" \
+    qaws
+        --groups      "/ecs/myservice0"
+        --time        "1y" "2020-05-24T00:00:00"
         --query       "fields @message | filter @message like 'event'"
-    qaws.py \
-        --groups      "/ecs/myservice0" \
-        --time        "2020-05-24T00:00:00" "5h" \
+    qaws
+        --groups      "/ecs/myservice0"
+        --time        "2020-05-24T00:00:00" "5h"
         --query       "fields @message | filter @message like 'event' | limit 15"
-
 AUTHORS
     Jiri Kacirek (kacirek.j@gmail.com) 2020
 IMPLEMENTATION
@@ -135,6 +138,7 @@ def main(argv=None):
     arg_groups_names = []
     arg_time = []
     arg_query = []
+    arg_separator = []
     _switch_pointer = []
 
     for idx, item in enumerate(argv):
@@ -147,6 +151,9 @@ def main(argv=None):
         if item in ['--query', '-q']:
             _switch_pointer = arg_query
             continue
+        if item in ['--separator', '-s']:
+            _switch_pointer = arg_separator
+            continue
 
         _switch_pointer.append(item)
 
@@ -200,6 +207,8 @@ def main(argv=None):
                 line.append(r['value'].strip())
 
         line = ', '.join(line)
+        if len(arg_separator) != 0:
+            line = arg_separator[0] + line
         print(line)
 
     return 0
